@@ -2,6 +2,8 @@
 #define SIMD_FORCE_READ(var) __asm__("" ::"x"(var));
 #elif defined(__GNUC__) && defined(__aarch64__)
 #define SIMD_FORCE_READ(var) __asm__("" ::"w"(var));
+#elif defined(__s390x__)
+#define SIMD_FORCE_READ(var) __asm__("" ::"d"(var));
 #else
 #define SIMD_FORCE_READ(var)
 #endif
